@@ -76,14 +76,6 @@ lw_applet_realize (GtkWidget *widget)
 
     desktop_plugin_visible_notify((GObject *)widget, NULL, desktop_plugin);
 
-#if 0
-    /* Load config */
-    read_config(desktop_plugin->priv);
-
-    init_scene_theme(desktop_plugin);
-        
-    desktop_plugin->priv->long_timer = g_timeout_add(LONG_TIMER, (GtkFunction)long_timeout, desktop_plugin);
-#endif
     screen = gtk_widget_get_screen (widget);
     gtk_widget_set_colormap (widget,
                                 gdk_screen_get_rgba_colormap (screen));
